@@ -679,7 +679,7 @@ let atts2impl loc ~depth state atts q =
         match Pcoq.parse_string (Pvernac.main_entry None) (Printf.sprintf "#[%s] Qed." txt) |> Option.map (fun x -> x.CAst.v) with
         | None -> atts
         | Some { Vernacexpr.attrs ; _ } -> List.map (fun {CAst.v=(name,v)} -> convert_att_r ("elpi."^name,v)) attrs @ atts
-        | exception Stream.Error msg ->
+        | exception Gramlib.Stream.Error msg ->
             CErrors.user_err Pp.(str"Environment variable COQ_ELPI_ATTRIBUTES contains ill formed value:" ++ spc () ++ str txt ++ cut () ++ str msg) in
   let state, atts, _ = EU.map_acc (Coq_elpi_builtins.attribute.API.Conversion.embed ~depth) state atts in
   let atts = ET.mkApp attributesc (EU.list_to_lp_list atts) [] in
@@ -700,6 +700,7 @@ let run_program loc name ~atts args =
       state args in
     let state, q = atts2impl loc ~depth state atts (ET.mkApp mainc (EU.list_to_lp_list args) []) in
     let state = API.State.set Coq_elpi_builtins.tactic_mode state false in
+    let state = API.State.set Coq_elpi_builtins.invocation_site_loc state loc in
     state, (loc, q), gls in
 
   run_and_print ~print:false ~static_check:false name program (`Fun query)
@@ -773,6 +774,7 @@ let run_tactic_common loc ?(static_check=false) program ~main ?(atts=[]) () =
         ~in_elpi_tac_arg:Coq_elpi_arg_HOAS.in_elpi_tac ~depth state in
     let state, qatts = atts2impl loc ~depth state atts q in
     let state = API.State.set Coq_elpi_builtins.tactic_mode state true in
+    let state = API.State.set Coq_elpi_builtins.invocation_site_loc state loc in
     state, (loc, qatts), gls
     in
   let cprogram, _ = get_and_compile program in
